@@ -17,78 +17,19 @@ globalVariables('panel_')
 #' example(metaplot.data.frame)
 metaplot <- function(x,...)UseMethod('metaplot')
 
-#' Categorical Plot
-#'
-#' Categorical plot.  Currently unimplemented. Returns a named vector indicating whether anonymous arguments were detected as numeric or categorical.
-#'
-#' @param x data.frame
-#' @param ... other arguments
-#' @family categorical
-#' @family metaplot
-#' @return character
-#' @export
-#' @importFrom rlang quos
-#'
-categorical <- function(x,...){
-  args <- quos(...)
-  args <- lapply(args,f_rhs)
-  vars <- args[names(args) == '']
-  other <- args[names(args) != '']
-  vars <- sapply(vars, as.character)
-  stopifnot(all(vars %in% names(x)))
-  num <- with(x, sapply(vars, is.numeric))
-
-  guide <- with(x, lapply(vars, attr, 'guide'))
-  guide[is.null(guide)] <- ''
-  stopifnot(all(sapply(guide,length) <= 1))
-  guide <- as.character(guide)
-
-  label <- with(x, lapply(vars, attr, 'label'))
-  label[is.null(label)] <- ''
-  stopifnot(all(sapply(label,length) <= 1))
-  label <- as.character(label)
-
-  encoded <- with(x, sapply(vars, encoded))
-  num[encoded] <- FALSE
-  num <- ifelse(num,'numeric','categorical')
-  names(num) <- vars
-  warning('categorical() is currently unimplemented')
-  num
-}
-
-#' Create Metaplot from Folded
-#'
-#' Creates a plot from folded.  Packs metadata into attributes and calls next method.
-#'
-
-#' @param x object
-#' @param ... passed arguments
-#' @family metaplot
-#' @family univariate plots
-#' @family bivariate plots
-#' @family multivariate plots
-#' @importFrom graphics boxplot
-#' @importFrom stats as.formula cor density loess.smooth median
-#' @importFrom dplyr filter
-#' @import fold
-#' @export
-
-metaplot.folded <- function(x, ...)metaplot(pack(x,...),...)
-
-
 #' Create Metaplot for Data Frame.
 #'
-#' Metaplot creates univariate, bivariate, or multivariate plots depending on the number and types of variables represented by the anonymous arguments.  Types are either numeric (NUM, e.g. real, integer) or categorical (CAT, e.g. factor, character).  A variable stored as numeric that nonetheless has an \code{\link[encode]{encoded}} \code{guide} attribute will be treated as categorical.
+#' Metaplot creates univariate, bivariate, or multivariate plots depending on the number and types of variables represented by the anonymous arguments.  Types are either numeric (NUM, e.g. real, integer) or categorical (CAT, e.g. factor, character).  A variable stored as numeric that nonetheless has an \code{\link[encode]{encode}}d \code{guide} attribute will be treated as categorical.
 #'
 #' Design your plot by specifying y variables (optional), the x variable, the groups variable (optional) and the conditioning variables (i.e., facets, optional).
 #'
-#' The single groups variable, if any, is the first categorical in the third position or later. An earlier categorical gives a bivariate plot, e.g. horizontal boxplot (first position) or vertical boxplot (second postion) causing groups and facets to be ignored.
+#' The single groups variable, if any, is the first categorical in the third position or later. An earlier categorical gives a "mixed" bivariate plot, e.g. horizontal boxplot (first position) or vertical boxplot (second postion) which is implicitly grouped.
 #'
 #' The x variable is the last variable before groups, if present.
 #'
 #' The y variables are those before x. If none, the result is univariate. If one, the result is typically a boxplot or scatterplot, depending on x. Several numeric y followed by a numeric x are treated as multivariate (scatterplot matrix).  But if all y have the same \code{guide} attribute and it is different from that for x, the result is bivariate (i.e, an \code{overlay} scatterplot).
 #'
-#' The groups argument is only relevant for bivariate plots with one y.  For multiple y (overlay), the sources of y are the implied groups: any trailing categorical arguments are treated as facets. To specify facets without specifying groups, let groups be empty, e.g., \code{(metaplot(y, x, , facet1, facet2))}.
+#' The groups argument is only relevant for bivariate plots with one y (but see \code{\link{densplot.data.frame}}).  For multiple y (overlay), the sources of y are the implied groups: any trailing categorical arguments are treated as facets. To specify facets without specifying groups, let groups be empty, e.g., \code{(metaplot(y, x, , facet1, facet2))}.
 #'
 #' Template designs follow; substitute behaviors by setting global options (see argument list).
 #'
@@ -97,14 +38,16 @@ metaplot.folded <- function(x, ...)metaplot(pack(x,...),...)
 #'
 #' \item{CAT:}{ categorical (unimplemented) }
 #'
-#' \item{NUM, CAT:}{mixedvariate (vertical boxplot)}
-#'
-#' \item{CAT, NUM:}{mixedvariate (horizontal boxplot)}
-#'
-#' \item{NUM, NUM:}{bivariate (scatterplot)}
-#'
 #'\item{CAT, CAT:}{ categorical (unimplemented)}
 #'
+#' \item{NUM, CAT:}{ mixedvariate (vertical boxplot)}
+#'
+#' \item{CAT, NUM:}{ mixedvariate (horizontal boxplot)}
+#'
+#' \item{CAT, NUM, CAT:}{ mixedvariate with one facet}
+#'
+#' \item{NUM, NUM:}{ bivariate (scatterplot)}
+#'
 #' \item{NUM, NUM, CAT:}{ grouped bivariate (grouped scatterplot)}
 #'
 #' \item{NUM, NUM,, CAT:}{ non-grouped bivariate with one facet}
@@ -172,7 +115,7 @@ metaplot.folded <- function(x, ...)metaplot(pack(x,...),...)
 #' attr(x$arm,'label') <- 'trial arm'
 #' attr(x$site,'label') <- 'investigational site'
 #' attr(x$pred,'label') <- 'population-predicted concentration'
-#' attr(x$ipred,'label') <- 'individual-predicted conentration'
+#' attr(x$ipred,'label') <- 'individual-predicted concentration'
 #' attr(x$res,'label') <- 'residuals'
 #' attr(x$sres,'label') <- 'standardized residuals'
 #' attr(x$lKe,'label') <- 'natural log of elimination rate constant'
@@ -203,8 +146,12 @@ metaplot.folded <- function(x, ...)metaplot(pack(x,...),...)
 #' x %>% metaplot(conc)
 #'#x %>% metaplot(site)
 #' x %>% metaplot(Wt, arm)
+#' x %>% densplot(Wt, arm)
 #' x %>% metaplot(arm, Wt)
+#' x %>% metaplot(Wt, arm, site)
+#' x %>% metaplot(Wt, site, arm)
 #' x %>% metaplot(conc, Time)
+#' x %>% metaplot(conc, Time, panel = panel.smoothScatter)
 #'#x %>% metaplot(arm, site)
 #' x %>% metaplot(conc, Time, Subject)
 #' x %>% metaplot(conc, Time, , Subject)
@@ -213,9 +160,11 @@ metaplot.folded <- function(x, ...)metaplot(pack(x,...),...)
 #' x %>% metaplot(lKe, lKa, lCl)
 #' x %>% metaplot(conc, ipred, Time)
 #' x %>% metaplot(conc, ipred, Time, Subject)
+#' x %>% metaplot(conc, ipred, Time, Subject, colors = 'black', points = c(T,F), lines = c(F,T))
 #' x %>% metaplot(conc, ipred, Time, site, arm)
 #' x %>% metaplot(res, conc, yref = 0, ysmooth = T, conf = T, grid = T, loc = 1)
-#' x %>% metaplot(conc, Time, panel = panel.smoothScatter)
+#' x %>% metaplot(res, conc, arm, ysmooth = T, conf = T )
+#' x %>% metaplot(res, conc, arm, ysmooth = T, conf = T, global = T)
 #'
 #'\dontshow{
 #'\dontrun{
@@ -229,6 +178,7 @@ metaplot.folded <- function(x, ...)metaplot(pack(x,...),...)
 #'#y %>% metaplot(site)
 #' y %>% metaplot(Wt, arm)
 #' y %>% metaplot(arm, Wt)
+#' y %>% metaplot(arm, Wt,site)
 #' y %>% metaplot(conc, Time)
 #'#y %>% metaplot(arm, site)
 #' y %>% metaplot(conc, Time, Subject)
@@ -238,13 +188,16 @@ metaplot.folded <- function(x, ...)metaplot(pack(x,...),...)
 #' y %>% metaplot(lKe, lKa, lCl)
 #' y %>% scatter(conc, ipred, Time)
 #' y %>% scatter(conc, ipred, Time, Subject)
+#' x %>% metaplot(conc, ipred, Time, Subject, colors = 'black', points = c(T,F), lines = c(F,T))
+#' y %>% scatter(conc, ipred, Time, site, arm)
+#' y %<>% mutate(Time = ifelse(Time > 15, NA, Time))
 #' y %>% scatter(conc, ipred, Time, site, arm)
 #'}}
 #'
 metaplot.data.frame <- function(
   x,
   ...,
-  univariate   = getOption('metaplot_univariate','dens'),
+  univariate   = getOption('metaplot_univariate','densplot'),
   mixedvariate = getOption('metaplot_mixedvariate','boxplot'),
   bivariate    = getOption('metaplot_bivariate','scatter'),
   multivariate = getOption('metaplot_multivariate','corsplom'),
