@@ -9,18 +9,22 @@ globalVariables('metaplot_values')
 #' @param ... passed arguments
 #' @export
 #' @family generic functions
+#' @family scatter
+#' @family bivariate plots
+#' @family metaplot
 scatter <- function(x,...)UseMethod('scatter')
 
 #' Scatterplot Function for Data Frame
 #'
-#' Scatterplot function for class 'data.frame'. Uses standard evaluation.
+#' Scatterplot function for class 'data.frame'.
 #'
 #'
 #' @param x data.frame
 #' @param yvar character: y variable(s)
 #' @param xvar character: x variable
-#' @param groups optional grouping item; ignored if more than one \code{yvar}
-#' @param facets character: up to two grouping items
+#' @param groups optional grouping variable; ignored if more than one \code{yvar}
+#' @param facets optional conditioning variables
+#' @param log a default sharede by \code{ylog} and \code{xlog}
 #' @param ylog log transform y axis (guessed if NULL)
 #' @param xlog log transform x axis (guessed if NULL)
 #' @param yref reference line from y axis
@@ -29,22 +33,23 @@ scatter <- function(x,...)UseMethod('scatter')
 #' @param xsmooth supply loess smmoth of x on y
 #' @param ylab y axis label, constructed from attributes \code{label} and \code{guide} if available
 #' @param xlab x axis label, constructed from attributes \code{label} and \code{guide} if available
-#' @param cols suggested columns for auto.key
-#' @param density plot point density instead of points (ignored if \code{groups} is supplied)
-#' @param iso use isometric axes with line of unity
-#' @param main logical: whether to construct a default title; or a substitute title or NULL
-#' @param corr append Pearson correlation coefficient to default title (only if main is \code{TRUE})
+#' @param iso plot line of unity
 #' @param crit if ylog or xlog missing, log transform if mean/median ratio for non-missing values is greater than crit
 #' @param na.rm whether to remove data points with one or more missing coordinates
-#' @param fit draw a linear fit of y ~ x
-#' @param conf logical, or width for a confidence region around a linear fit; passed to \code{\link{region}}; \code{TRUE} defaults to 95 percent confidence interval
-#' @param log a default sharede by \code{ylog} and \code{xlog}
-#' @param msg a function to print text on a panel: called with x values, y values, and \dots.
-#' @param loc where to print statistics on a panel
-#' @param aspect tpassed to \code{\link[lattice]{xyplot}}
+#' @param aspect passed to \code{\link[lattice]{xyplot}}
 #' @param auto.key passed to \code{\link[lattice]{xyplot}}
+#' @param keycols number of auto.key columns
 #' @param as.table passed to \code{\link[lattice]{xyplot}}
+#' @param prepanel passed to \code{\link[lattice]{xyplot}} (guessed if NULL)
+#' @param scales passed to \code{\link[lattice]{xyplot}} (guessed if NULL)
 #' @param panel name or definition of panel function
+#' @param colors replacements for default colors in group order
+#' @param symbols replacements for default symbols in group order
+#' @param points whether to plot points for each group: logical, or alpha values between 0 and 1
+#' @param lines whether to plot lines for each group: logical, or alpha values between 0 and 1
+#' @param main character, or a function of x, yvar, xvar, groups, facets, and log
+#' @param sub character, or a function of x, yvar, xvar, groups, facets, and log
+
 #' @param ... passed to \code{\link{region}}
 #' @seealso \code{\link{metapanel}}
 #' @export
@@ -65,14 +70,18 @@ scatter <- function(x,...)UseMethod('scatter')
 #' scatter_data_frame(Theoph, 'conc','Time', facets = 'Subject')
 #' scatter_data_frame(Theoph %>% filter(conc > 0), 'conc','Time', 'Subject',ylog = TRUE, yref = 5)
 #' scatter_data_frame(Theoph, 'conc','Time', 'Subject',ysmooth = TRUE)
-#' scatter_data_frame(Theoph, 'conc','Time', main = TRUE, corr = TRUE)
+#' scatter_data_frame(Theoph, 'conc','Time', 'Subject',ysmooth = TRUE,global = TRUE)
 #' scatter_data_frame(Theoph, 'conc','Time', conf = TRUE, loc = 3, yref = 6)
+#' scatter_data_frame(Theoph, 'conc','Time', conf = TRUE, loc = 3, yref = 6)
+
+
 scatter_data_frame <- function(
   x,
   yvar,
   xvar,
   groups = NULL,
   facets = NULL,
+  log = FALSE,
   ylog = log,
   xlog = log,
   yref = NULL,
@@ -81,42 +90,38 @@ scatter_data_frame <- function(
   xlab = NULL,
   ysmooth = FALSE,
   xsmooth = FALSE,
-  cols = NULL,
-  density = FALSE,
   iso = FALSE,
-  main = FALSE,
-  corr = FALSE,
   crit = 1.3,
   na.rm = TRUE,
-  fit = conf,
-  conf = FALSE,
-  loc = 0,
   aspect = 1,
   auto.key = NULL,
+  keycols = NULL,
   as.table = TRUE,
-  log = FALSE,
-  msg = 'metastats',
+  prepanel = NULL,
+  scales = NULL,
   panel = metapanel,
+  colors = NULL,
+  symbols = NULL,
+  points = TRUE,
+  lines = FALSE,
+  main = getOption('metaplot_main',NULL),
+  sub = getOption('metaplot_sub',NULL),
+
   ...
 ){
   stopifnot(inherits(x, 'data.frame'))
-  stopifnot(is.logical(corr))
   stopifnot(length(groups) <= 1)
   stopifnot(is.character(yvar))
   stopifnot(is.character(xvar))
   stopifnot(length(xvar) == 1)
-  if(is.null(cols))if(length(yvar) > 1)cols <- 1
-  if(is.null(cols))if(length(yvar) == 1)cols <- 3
-  if(is.null(auto.key)) auto.key = list(columns = cols)
 
   if(!is.null(facets))stopifnot(is.character(facets))
-  # if(length(var) < 2) stop('need two items to make scatterplot')
-  # if(length(var) > 2) warning('only using first two of supplied var items')
   y <- x
   stopifnot(all(c(xvar,yvar,groups,facets) %in% names(y)))
-  if(length(yvar) > 1){
-    if(any(c('metaplot_groups','metaplot_values') %in% names(y)))
+  if(any(c('metaplot_groups','metaplot_values') %in% names(y)))
       stop('metaplot_groups and metaplot_values are reserved and cannot be column names')
+  if(length(yvar) > 1){
+    if(is.null(keycols))if(length(yvar) > 1)keycols <- 1
     suppressWarnings(y %<>% gather(metaplot_groups, metaplot_values, !!!yvar))
     groups <- 'metaplot_groups'
     labs <- sapply(yvar, function(col){
@@ -138,7 +143,13 @@ scatter_data_frame <- function(
     if(length(gui) == 1) attr(y$metaplot_values, 'guide') <- gui
     yvar <- 'metaplot_values'
   }
-  if(na.rm) y %<>% filter(is.defined(!!yvar) & is.defined(!!xvar)) # preserves attributes
+  if(is.null(groups)){
+    y$metaplot_groups <- TRUE
+    groups <- 'metaplot_groups'
+  }
+  if(is.null(keycols))keycols <- min(3, length(unique(y[[groups]])))
+  if(is.null(auto.key))if(length(unique(y[[groups]])) > 1) auto.key = list(columns = keycols,points=TRUE,lines=TRUE)
+  if(na.rm) y %<>% filter(is.defined(UQ(yvar)) & is.defined(UQ(xvar))) # preserves attributes
   ff <- character(0)
   if(!is.null(facets))ff <- paste(facets, collapse = ' + ')
   if(!is.null(facets))ff <- paste0('|',ff)
@@ -161,49 +172,46 @@ scatter_data_frame <- function(
   if(length(xref) & xlog & !(any(xref <= 0))) xref <- log10(xref)
   yscale = list(log = ylog,equispaced.log = FALSE)
   xscale = list(log = xlog,equispaced.log = FALSE)
-  scales = list(y = yscale,x = xscale,tck = c(1,0),alternating = FALSE)
+  if(is.null(scales)) scales <- list(y = yscale,x = xscale,tck = c(1,0),alternating = FALSE)
   if(is.null(ylab))ylab <- axislabel(y,var = yvar, log = ylog)
   ylab <- sub('metaplot_values','',ylab)
   if(is.null(xlab))xlab <- axislabel(y,var = xvar, log = xlog)
-  ifcoded <- function(x, var){
-    guide <- attr(x[[var]],'guide')
-    if(!encoded(guide)) return(x[[var]])
-    decoded <- decode(x[[var]], encoding = guide)
-    if(!any(is.na(decoded))) return(decoded)
-    if(all(is.na(decoded)))return(decode(x[[var]]))
-    x[[var]]
-  }
-  if(!is.null(groups))y[[groups]] <- ifcoded(y, groups)
+  # if (is.null(groups)) # cannot be null at this point
+  y[[groups]] <- ifcoded(y, groups)
+  if(!is.null(main))if(is.function(main)) main <- main(x = y,yvar = yvar, xvar = xvar, groups = groups, facets = facets, log = log, ...)
+  if(!is.null(sub))if(is.function(sub)) sub <- sub(x = y, yvar = yvar, xvar = xvar, groups = groups, facets = facets, log = log, ...)
+
+  groups <- as.formula(paste('~',groups))
   if(!is.null(facets)){
     for (i in seq_along(facets)) y[[facets[[i]]]] <- ifcoded(y, facets[[i]])
   }
-  prepanel = if(iso) function(x,y,...){
+  if(is.null(prepanel))if(iso) prepanel <- function(x,y,...){
     lim = c(min(x,y,na.rm = T),max(x,y,na.rm = T))
     list(
       xlim = lim,
       ylim = lim
     )
-  } else NULL
-  cor <- cor(
-    use = 'pair',
-    if(ylog) log(y[[yvar]]) else y[[yvar]],
-    if(xlog) log(y[[xvar]]) else y[[xvar]]
-  )
-  cor <- signif(cor,2)
-  cor <- paste('R =',cor)
-  cor <- parens(cor)
-  mn <- paste(sep = ' ~ ',yvar,xvar)
-  if(length(groups)) mn <- paste(mn,'by',groups)
-  if(corr) mn <- paste(mn, cor)
-  mn <- list(mn, cex = 1, fontface = 1)
-  if(is.logical(main)){
-    if(main){
-      main <- mn
-    }else{
-      main <- NULL
-    }
   }
-  if(!is.null(groups)) groups <- as.formula(paste('~',groups))
+
+  if(!is.null(points)) points <- as.numeric(points)
+  if(!is.null(lines)) lines <- as.numeric(lines)
+  sym <- list(
+    col = colors,
+    alpha = points,
+    pch = symbols
+  )
+  line <- list(
+    col = colors,
+    alpha = lines
+  )
+  sym <- sym[sapply(sym,function(i)!is.null(i))]
+  line <- line[sapply(line,function(i)!is.null(i))]
+  pars <- list(
+    superpose.symbol = sym,
+    superpose.line = line
+  )
+  pars <- pars[sapply(pars, function(i)length(i) > 0 )]
+
   xyplot(
     formula,
     data = y,
@@ -219,47 +227,21 @@ scatter_data_frame <- function(
     xsmooth = xsmooth,
     ylab = ylab,
     xlab = xlab,
-    density = density,
     iso = iso,
-    main = main,
-    fit = fit,
-    conf = conf,
-    loc = loc,
-    msg = msg,
     panel = panel,
+    subscripts = TRUE,
+    par.settings = pars,
+    main = main,
+    sub = sub,
     ...
   )
 }
 
 #' Scatterplot Method for Data Frame
 #'
-#' Scatterplot method for class 'data.frame'. Uses nonstandard evaluation. By default, passes arguments to \code{\link{scatter_data_frame}}.
+#' Scatterplot method for class 'data.frame'. Parses arguments and generates the call: fun(x, yvar, xvar, groups, facets, ...).
 #' @param x data.frame
-#' @param ... unquoted names for variables: y, x, groups (may be missing) and conditioning variables (facets)
-#' @param ylog log transform y axis (guessed if NULL)
-#' @param xlog log transform x axis (guessed if NULL)
-#' @param yref reference line from y axis
-#' @param xref reference line from x axis
-#' @param ysmooth supply loess smooth of y on x
-#' @param xsmooth supply loess smmoth of x on y
-#' @param ylab y axis label, constructed from attributes \code{label} and \code{guide} if available
-#' @param xlab x axis label, constructed from attributes \code{label} and \code{guide} if available
-#' @param cols suggested columns for auto.key
-#' @param density plot point density instead of points (ignored if \code{groups} is supplied)
-#' @param iso use isometric axes with line of unity
-#' @param main logical: whether to construct a default title; or a substitute title or NULL
-#' @param corr append Pearson correlation coefficient to default title (only if main is \code{TRUE})
-#' @param crit if ylog or xlog missing, log transform if mean/median ratio for non-missing values is greater than crit
-#' @param na.rm whether to remove data points with one or more missing coordinates
-#' @param fit draw a linear fit of y ~ x
-#' @param conf logical, or width for a confidence region around a linear fit; passed to \code{\link{region}}; \code{TRUE} defaults to 95 percent confidence interval
-#' @param log a default shared by \code{ylog} and \code{xlog}
-#' @param msg a function to print text on a panel: called with x values, y values, and \dots.
-#' @param loc where to print statistics on a panel
-#' @param aspect passed to \code{\link[lattice]{xyplot}}
-#' @param auto.key passed to \code{\link[lattice]{xyplot}}
-#' @param as.table passed to \code{\link[lattice]{xyplot}}
-#' @param panel name or definition of panel function
+#' @param ... passed to fun
 #' @param fun function to draw the plot
 #' @seealso \code{\link{scatter_data_frame}}
 #' @export
@@ -279,36 +261,21 @@ scatter_data_frame <- function(
 #' scatter(Theoph, conc, Time, Subject) # Subject as groups
 #' scatter(Theoph, conc, Time, , Subject) # Subject as facet
 #' scatter(Theoph %>% filter(conc > 0), conc, Time, Subject, ylog = TRUE, yref = 5)
-#' scatter(Theoph, conc, Time, Subject,ysmooth = TRUE)
-#' scatter(Theoph, conc, Time, main = TRUE, corr = TRUE)
+#' scatter(Theoph, conc, Time, Subject, ysmooth = TRUE)
 #' scatter(Theoph, conc, Time, conf = TRUE, loc = 3, yref = 6)
+#' scatter(Theoph, conc, Time, conf = TRUE, loc = 3, yref = 6, global = TRUE)
+#' \dontrun{
+#' \dontshow{
+#' attr(Theoph,'title') <- 'Theophylline'
+#' scatter(Theoph, conc, Time, main = function(x,...)attr(x,'title'))
+#' scatter(Theoph, conc, Time, sub= function(x,...)attr(x,'title'))
+#' options(metaplot_main = function(x,...)attr(x,'title'))
+#' scatter(Theoph, conc, Time)
+#' }
+#' }
 scatter.data.frame <- function(
   x,
   ...,
-  ylog = log,
-  xlog = log,
-  yref = NULL,
-  xref = NULL,
-  ylab = NULL,
-  xlab = NULL,
-  ysmooth = FALSE,
-  xsmooth = FALSE,
-  density = FALSE,
-  iso = FALSE,
-  main = FALSE,
-  corr = FALSE,
-  na.rm = TRUE,
-  conf = FALSE,
-  fit = conf,
-  loc = 0,
-  aspect = 1,
-  cols = NULL,
-  crit = 1.3,
-  auto.key = NULL,
-  as.table = TRUE,
-  log = FALSE,
-  msg = 'metastats',
-  panel = metapanel,
   fun = getOption('metaplot_scatter','scatter_data_frame')
 ){
   args <- quos(...)
@@ -318,15 +285,15 @@ scatter.data.frame <- function(
   vars <- sapply(vars, as.character)
 
   # this function needs to explicitly assign xvar, yvar, groups, and facets
-  # prime is all y, if present, and x
+  # prime is all yvar, if present, and xvar
   # prime is defined as all vars before groups or facets, if present
   # non-prime start with the first missing or categorical in position 3 or later
   # since groups may be missing, checking properties may fail
   # isolate non-prime
   missing <- match('',vars)
   if(is.defined(missing)){
-    prime <- vars[seq_len(missing - 1)]
-    if(length(vars) > missing) nonpr <- vars[(missing+1):length(vars)]
+    #prime <- vars[seq_len(missing - 1)]
+    #if(length(vars) > missing) nonpr <- vars[(missing+1):length(vars)]
     vars <- vars[-missing]
   }
   # now we have protected vars from missingness, but preserved info from missing group, if any
@@ -376,34 +343,8 @@ scatter.data.frame <- function(
     yvar = yvar,
     xvar = xvar,
     groups = groups,
-    facets = facets,
-    ylog = ylog,
-    xlog = xlog,
-    yref = yref,
-    xref = xref,
-    ylab = ylab,
-    xlab = xlab,
-    ysmooth = ysmooth,
-    xsmooth = xsmooth,
-    density = density,
-    iso = iso,
-    main = main,
-    corr = corr,
-    na.rm = na.rm,
-    conf = conf,
-    fit = fit,
-    loc = loc,
-    aspect = aspect,
-    # cols = cols,
-    crit = crit,
-    # auto.key = auto.key,
-    as.table = as.table,
-    msg = msg,
-    panel = panel
+    facets = facets
   )
-  if(!is.null(cols))formal <- c(formal, list(cols = cols)) # fun is better at picking defaults
-  if(!is.null(auto.key))formal <- c(formal, list(auto.key = auto.key))
-
   args <- c(formal, other)
   do.call(match.fun(fun), args)
 }
@@ -421,47 +362,97 @@ scatter.data.frame <- function(
 #' @param xref reference line from x axis
 #' @param ysmooth supply loess smooth of y on x
 #' @param xsmooth supply loess smmoth of x on y
-#' @param density plot point density instead of points
 #' @param iso use isometric axes with line of unity
+#' @param global if TRUE, xsmooth, ysmooth, fit, and conf are applied to all data rather than groupwise
 #' @param fit draw a linear fit of y ~ x
 #' @param conf logical, or width for a confidence region around a linear fit; passed to \code{\link{region}}; \code{TRUE} defaults to 95 percent confidence interval
-#' @param loc where to print statistics on a panel
+#' @param loc where to print statistics on a panel; suppressed for grouped plots
 #' @param msg a function to print text on a panel: called with x values, y values, and \dots.
-#' @param ... passed to panel.superpose, panel.smoothScatter, panel.xyplot, panel.polygon, region, panel.text
+#' @param type overridden by metapanel
+#' @param ... passed to panel.superpose, panel.xyplot, panel.polygon, region, panel.text
 #' @family panel functions
-#' @family metaplots
+#' @family scatter
 #' @seealso \code{\link{metastats}}
 #' @seealso \code{\link{scatter.data.frame}}
 #'
-metapanel <- function(x, y, groups = NULL, xref = NULL, yref = NULL, ysmooth = FALSE, xsmooth = FALSE, density = FALSE, iso = FALSE, fit = conf, conf = FALSE, loc = 0, msg = 'metastats', ...)
+metapanel <- function(
+  x,
+  y,
+  groups,
+  xref = NULL,
+  yref = NULL,
+  ysmooth = FALSE,
+  xsmooth = FALSE,
+  fit = conf,
+  conf = FALSE,
+  loc = 0,
+  iso = FALSE,
+  global = FALSE,
+  msg = 'metastats',
+  type,
+  ...
+)
 {
-
-  if( length(groups))panel.superpose(
-    x = x,
-    y = y,
-    groups = groups,
-    panel.groups = function(x,y,lty,type,...){
-      panel.xyplot(x,y,...)
-      foo <- try(silent = TRUE, suppressWarnings(loess.smooth(x,y, family = 'gaussian')))
-      bar <- try(silent = TRUE, suppressWarnings(loess.smooth(y,x, family = 'gaussian')))
-      if(ysmooth && !inherits(foo,'try-error'))try(panel.xyplot(foo$x,foo$y,lty = 'dashed',type = 'l',...))
-      if(xsmooth && !inherits(bar,'try-error'))try(panel.xyplot(bar$y,bar$x,lty = 'dashed',type = 'l',...))
-    },
-    ...
-  )
-  if(!length(groups)){
-    if( density)panel.smoothScatter(x,y,...)
-    if(!density)panel.xyplot(x,y,...)
-    foo <- try(silent = TRUE, suppressWarnings(loess.smooth(x,y, family = 'gaussian')))
+  # if(is.null(groups)) groups <- rep(TRUE,length(x)) # cannot be NULL
+  myxsmooth <- function(x,y,type,lty,col, col.symbol, col.line,...){
     bar <- try(silent = TRUE, suppressWarnings(loess.smooth(y,x, family = 'gaussian')))
-    if(ysmooth && !inherits(foo,'try-error'))try(panel.xyplot(foo$x,foo$y,col = 'black',lty = 'dashed',type = 'l'))
-    if(xsmooth && !inherits(bar,'try-error'))try(panel.xyplot(bar$y,bar$x,col = 'black',lty = 'dashed',type = 'l'))
+    if(xsmooth && !inherits(bar,'try-error'))try(panel.xyplot(bar$y,bar$x,lty = 'dashed',type = 'l',col = col.line,...))
   }
-  f <- data.frame()
-  if(fit || conf) f <- region(x, y, conf = conf, ...)
-  if(fit) try(panel.xyplot(x=f$x, y=f$y, col='black', type='l', ...))
-  if(conf)try(panel.polygon(x = c(f$x, rev(f$x)),y = c(f$lo, rev(f$hi)),col='grey', border = FALSE, alpha=0.2, ...))
-  if(sum(loc))panel = panel.text(x = xpos(loc), y = ypos(loc), label = match.fun(msg)(x = x, y = y, ...))
+  myysmooth <- function(x,y,type,lty,col, col.symbol, col.line,...){
+    foo <- try(silent = TRUE, suppressWarnings(loess.smooth(x,y, family = 'gaussian')))
+    if(ysmooth && !inherits(foo,'try-error'))try(panel.xyplot(foo$x,foo$y,lty = 'dashed',type = 'l',col = col.line,...))
+  }
+  myfit <- function(x,y,type,lty,col, col.symbol, col.line,...){
+    f <- data.frame()
+    f <- region(x, y, conf = conf, ...)
+    try(panel.xyplot(x=f$x, y=f$y, col= col.line, type='l', ...))
+  }
+  myconf <- function(x,y,type,lty,col, col.symbol, col.line,...){
+    f <- region(x, y, conf = conf, ...)
+    try(panel.polygon(
+      x = c(f$x, rev(f$x)),
+      y = c(f$lo, rev(f$hi)),
+      border = FALSE,
+      alpha=0.2,
+      col=col.symbol
+    ))
+  }
+  superpose.line <- trellis.par.get()$superpose.line
+  panel.superpose(x = x,y = y,groups = groups,panel.groups = panel.lines,type='l',alpha = superpose.line$alpha, ...)
+  panel.superpose(x = x,y = y,groups = groups,panel.groups = panel.points,type='p',...)
+  if(conf){
+    if(global){
+      myconf(x,y, col = 'grey', col.symbol = 'grey', col.line = 'grey',...)
+    }else{
+      panel.superpose(x = x, y = y, groups = groups, panel.groups = myconf, ...)
+    }
+  }
+  if(fit){
+    if(global){
+      myfit(x,y, col = 'grey', col.symbol = 'grey', col.line = 'grey',...)
+    }else{
+      panel.superpose(x = x, y = y, groups = groups, panel.groups = myfit, ...)
+    }
+  }
+  if(ysmooth){
+    if(global){
+      myysmooth(x,y, col = 'grey', col.symbol = 'grey', col.line = 'grey',...)
+    }else{
+      panel.superpose(x = x, y = y, groups = groups, panel.groups = myysmooth, ...)
+    }
+  }
+  if(xsmooth){
+    if(global){
+      myxsmooth(x,y, col = 'grey', col.symbol = 'grey', col.line = 'grey',...)
+    }else{
+      panel.superpose(x = x, y = y, groups = groups, panel.groups = myxsmooth, ...)
+    }
+  }
+  if(sum(loc))panel = panel.text(
+    x = xpos(loc),
+    y = ypos(loc),
+    label = match.fun(msg)(x = x, y = y, ...)
+  )
   if(length(yref))panel.abline(h = yref)
   if(length(xref))panel.abline(v = xref)
   if(iso)panel.abline(0,1)
@@ -491,105 +482,3 @@ ypos <- function(loc){
   ypos
 }
 
-#' Scatterplot for Folded
-#'
-#' Scatterplot for class 'folded'.
-#' @export
-#' @import encode
-#' @import lattice
-#' @importFrom rlang UQS
-#' @family bivariate plots
-#' @family scatter
-#' @param x folded
-#' @param xvar x values
-#' @param yvar y values
-#' @param groups optional grouping item
-#' @param ... passed to \code{\link{region}}
-#' @param ylog reference line from y axis
-#' @param xlog reference line from x axis
-#' @param yref reference line from y axis
-#' @param xref reference line from x axis
-#' @param ysmooth supply loess smooth of y on x
-#' @param xsmooth supply loess smmoth of x on y
-#' @param cols default columns for auto.key
-#' @param auto.key passed to \code{\link[lattice]{xyplot}}
-#' @param density plot point density instead of points
-#' @param iso use isometric axes with line of unity
-#' @param main logical: whether to construct a default title; or a substitute title or NULL
-#' @param corr append Pearson correlation coefficient to default title (only if main is \code{TRUE})
-#' @param crit if ylog or xlog missing, log transform if mean/median ratio for non-missing values is greater than crit
-#' @param na.rm whether to remove data points with one or more missing coordinates
-#' @param fit draw a linear fit of y ~ x
-#' @param log default for ylog and xlog
-#' @param conf logical, or width for a confidence region around a linear fit; passed to \code{\link{region}}; \code{TRUE} defaults to 95 percent confidence interval
-#' @param loc where to print statistics on a panel
-#' @param msg a function to print text on a panel: called with x values, y values, and \dots.
-#' @param panel default panel function
-#
-scatter.folded <- function(
-  x,
-  yvar,
-  xvar,
-  groups = NULL,
-  ...,
-  ylog = log,
-  xlog = log,
-  yref = NULL,
-  xref = NULL,
-  ysmooth = FALSE,
-  xsmooth = FALSE,
-  cols = 3,
-  auto.key = list(columns = cols),
-  density = FALSE,
-  iso = FALSE,
-  main = FALSE,
-  corr = FALSE,
-  crit = 1.3,
-  na.rm = TRUE,
-  fit = conf,
-  log = FALSE,
-  conf = FALSE,
-  loc = 0,
-  msg = 'metastats',
-  panel = metapanel
-){
-  stopifnot(
-    length(xvar) == 1,
-    length(yvar) == 1,
-    length(groups) <= 1
-  )
-  y <- x %>% unfold(UQS(c(yvar,xvar,groups)))
-  stopifnot(all(c(xvar,yvar,groups) %in% names(y)))
-  gc <- if(length(groups)) guide(x,groups) else NULL
-  if(!is.null(gc))if(all(is.na(gc))) gc <- NULL
-  ylab <- axislabel(x,yvar,ylog)
-  xlab <- axislabel(x,xvar,xlog)
-  scatter_data_frame(
-    y,
-    yvar = yvar,
-    xvar = xvar,
-    ylab = ylab,
-    xlab = xlab,
-    groups = groups,
-    ylog = ylog,
-    xlog = xlog,
-    yref = yref,
-    xref = xref,
-    ysmooth = ysmooth,
-    xsmooth = xsmooth,
-    cols = cols,
-    density = density,
-    iso = iso,
-    main = main,
-    corr = corr,
-    group_codes = gc,
-    crit = crit,
-    na.rm = na.rm,
-    fit = fit,
-    conf = conf,
-    loc = loc,
-    msg = msg,
-    panel = panel,
-    ...
-  )
-}
